@@ -1,6 +1,6 @@
 /*
  * backend.h -- Interface exported by XBoard back end
- * $Id: backend.h,v 1.19 1995/03/09 00:43:28 mann Exp $
+ * $Id: backend.h,v 1.27 1996/11/17 05:57:41 mann Exp $
  *
  * Copyright 1991 by Digital Equipment Corporation, Maynard, Massachusetts.
  * Enhancements Copyright 1992-95 Free Software Foundation, Inc.
@@ -42,13 +42,18 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  * ------------------------------------------------------------------------
  */
+#include "lists.h"
+
 extern GameMode gameMode;
-extern int pausing, cmailMsgLoaded, flipView;
+extern int pausing, cmailMsgLoaded, flipView, ics_bughouse;
 extern FILE *fromUserFP, *toUserFP, *debugFP;
 
+void TimeDelay P((long ms));
+void SendMultiLineToICS P(( char *text ));
+void AnalysisPeriodicEvent P((int force));
 void SetWhiteToPlayEvent P((void));
 void SetBlackToPlayEvent P((void));
 void InitBackEnd1 P((void));
@@ -57,7 +62,8 @@ int IsPromotion P((int fromX, int fromY, int toX, int toY));
 int OKToStartUserMove P((int x, int y));
 void Reset P((int redraw));
 void ResetGameEvent P((void));
-int LoadGame P((FILE *f, int n, char *title));
+int LoadGame P((FILE *f, int n, char *title, int useList));
+int CmailLoadGame P((FILE *f, int n, char *title, int useList));
 int ReloadGame P((int offset));
 int SaveGame P((FILE *f, int dummy, char *dummy2));
 int LoadPosition P((FILE *f, int n, char *title));
@@ -88,6 +94,7 @@ void ResignEvent P((void));
 void StopObservingEvent P((void));
 void StopExaminingEvent P((void));
 void ShowThinkingEvent P((int newState));
+void PeriodicUpdatesEvent P((int newState));
 void HintEvent P((void));
 void BookEvent P((void));
 void AboutGameEvent P((void));
@@ -99,16 +106,62 @@ char *TimeString P((long millisec));
 void LoadGameLoop P((void));
 void DisplayBothClocks P((void));
 void EditPositionMenuEvent P((ChessSquare selection, int x, int y));
+void DropMenuEvent P((ChessSquare selection, int x, int y));
 int ParseTimeControl P((char *tc));
 void ProcessICSInitScript P((FILE * f));
 void EditCommentEvent P((void));
 void ReplaceComment P((int index, char *text));
+int ReplaceTags P((char *tags, GameInfo *gi));/* returns nonzero on error */
 void AppendComment P((int index, char *text));
-void ReloadCmailGameEvent P((int unregister));
+void ReloadCmailMsgEvent P((int unregister));
 void MailMoveEvent P((void));
+void EditTagsEvent P((void));
+void GetMoveListEvent P((void));
+void ExitAnalyzeMode P((void));
+void AnalyzeModeEvent P((void));
+void AnalyzeFileEvent P((void));
 
-int StrCaseCmp P((char *s1, char *s2));
 char *StrStr P((char *string, char *match));
+char *StrSave P((char *s));
+char *StrSavePtr P((char *s, char **savePtr));
+
+#ifndef _amigados
+int StrCaseCmp P((char *s1, char *s2));
 int ToLower P((int c));
 int ToUpper P((int c));
-char *StrSave P((char *s));
+#else
+#define StrCaseCmp Stricmp  /*  Use utility.library functions   */
+#include <proto/utility.h>
+#endif
+
+extern GameInfo gameInfo;
+
+
+
+/* pgntags.c prototypes
+ */
+char *PGNTags P((GameInfo *));
+void PrintPGNTags P((FILE *f, GameInfo *));
+int ParsePGNTag P((char *, GameInfo *));
+char *PGNResult P((ChessMove result));
+
+
+/* gamelist.c prototypes
+ */
+/* A game node in the double linked list of games.
+ */
+typedef struct _ListGame {
+    ListNode node;
+    int number;
+    unsigned long offset;   /*  Byte offset of game within file.     */
+    GameInfo gameInfo;      /*  Note that some entries may be NULL. */
+} ListGame;
+ 
+extern List gameList;
+void ClearGameInfo P((GameInfo *));
+int GameListBuild P((FILE *));
+void GameListInitGameInfo P((GameInfo *));
+char *GameListLine P((int, GameInfo *));
+
+extern char* StripHighlight P((char *));  /* returns static data */
+extern char* StripHighlightAndTitle P((char *));  /* returns static data */
