@@ -1,6 +1,6 @@
 /*
  * frontend.h -- Interface exported by all XBoard front ends
- * $Id: frontend.h,v 1.12 1995/03/09 00:43:28 mann Exp $
+ * $Id: frontend.h,v 1.18 1996/11/17 05:57:41 mann Exp $
  *
  * Copyright 1991 by Digital Equipment Corporation, Maynard, Massachusetts.
  * Enhancements Copyright 1992-95 Free Software Foundation, Inc.
@@ -42,10 +42,14 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  * ------------------------------------------------------------------------
  */
 
+#ifndef _FRONTEND
+#define _FRONTEND
+
+#include <stdio.h>
 
 void ModeHighlight P((void));
 void SetICSMode P((void));
@@ -53,7 +57,7 @@ void SetGNUMode P((void));
 void SetNCPMode P((void));
 void SetCmailMode P((void));
 void DisplayTitle P((String title));
-void DisplayMessage P((String message1, String message2));
+void DisplayMessage P((String message, String extMessage));
 void DisplayError P((String message, int error));
 void DisplayFatalError P((String message, int error, int status));
 void DisplayInformation P((String message));
@@ -88,8 +92,8 @@ int StartChildProcess P((char *cmdLine, ProcRef *pr));
 void DestroyChildProcess P((ProcRef pr));
 void InterruptChildProcess P((ProcRef pr));
 
-int OpenTelnet P((char *host, int port, ProcRef *pr));
-int OpenTCP P((char *host, int port, ProcRef *pr));
+int OpenTelnet P((char *host, char *port, ProcRef *pr));
+int OpenTCP P((char *host, char *port, ProcRef *pr));
 int OpenCommPort P((char *name, ProcRef *pr));
 int OpenLoopback P((ProcRef *pr));
 int OpenRcmd P((char *host, char *user, char *cmd, ProcRef *pr));
@@ -100,7 +104,25 @@ InputSourceRef AddInputSource P((ProcRef pr, int lineByLine, InputCallback func)
 void RemoveInputSource P((InputSourceRef isr));
 
 int OutputToProcess P((ProcRef pr, char *message, int count, int *outError));
+int OutputToProcessDelayed P((ProcRef pr, char *message, int count,
+			      int *outError, long msdelay));
 
 void CmailSigHandlerCallBack P((InputSourceRef isr, char *buf, int count, int error));
 
 extern ProcRef cmailPR;
+
+void GameListPopUp P((FILE *fp, char *filename));
+void GameListPopDown P((void));
+void GameListHighlight P((int index));
+void GameListDestroy P((void));
+
+void EditTagsPopUp P((char *tags));
+void TagsPopUp P((char *tags, char *msg));
+void TagsPopDown P((void));
+
+void ICSInitScript P((void));
+void StartAnalysisClock P((void));
+void AnalysisPopUp P((char *title, char *label));
+void AnalysisPopDown P((void));
+
+#endif
