@@ -1,6 +1,6 @@
 /*
  * xboard.h -- Parameter definitions for X front end
- * $Id: xboard.h,v 1.10 1995/03/09 00:43:28 mann Exp $
+ * $Id: xboard.h,v 1.19 1996/12/19 22:42:52 mann Exp $
  *
  * Copyright 1991 by Digital Equipment Corporation, Maynard, Massachusetts.
  * Enhancements Copyright 1992-95 Free Software Foundation, Inc.
@@ -42,17 +42,51 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  * ------------------------------------------------------------------------
  */
 
-#define ICS_LOGON               ".icsrc"
+#include <stdio.h>
+
+#define ICS_LOGON    ".icsrc"
+#define INFOFILE     "xboard.info"
+#define MANPAGE      "xboard.6"
 #define CLOCK_FONT   "-*-helvetica-bold-r-normal--*-*-*-*-*-*-*-*"
 #define COORD_FONT   "-*-helvetica-bold-r-normal--*-*-*-*-*-*-*-*"
 #define DEFAULT_FONT "*font: -*-helvetica-medium-r-normal--14-*-*-*-*-*-*-*"
+#define TINY_FONT \
+    "*tinyLayout*font: -*-helvetica-medium-r-normal--11-*-*-*-*-*-*-*"
+
+typedef struct {
+    char *name;
+    int squareSize;
+    int lineGap;
+    int clockFontPxlSize;
+    int coordFontPxlSize;
+    int smallLayout;
+    int tinyLayout;
+} SizeDefaults;
+
+#define SIZE_DEFAULTS \
+{ { "Large", 80, 3, 34, 14, 0, 0 }, \
+  { "Medium", 64, 3, 34, 12, 0, 0 }, \
+  { "Small", 40, 2, 20, 10, 1, 0 }, \
+  { "Smaller", 32, 1, 16, 9, 1, 1 }, \
+  { "Tiny", 21, 1, 12, 8, 1, 1 }, \
+  { NULL, 0, 0, 0, 0, 0, 0 } }
+
 #define BORDER_X_OFFSET 3
 #define BORDER_Y_OFFSET 27
+#define FIRST_CHESS_PROGRAM	"gnuchessx"
+#define SECOND_CHESS_PROGRAM	"gnuchessx"
 
-typedef enum {
-    Large, Medium, Small
-  } BoardSize;
+/* Default to no flashing (the "usual" XBoard behavior) */
+#define FLASH_COUNT	0		/* Number of times to flash */
+#define FLASH_RATE	5		/* Flashes per second */
+
+/* Default delay per character (in msec) while sending login script */
+#define MS_LOGIN_DELAY  0
+
+typedef int (*FileProc) P((FILE *f, int n, char *title));
+
+#define TOPLEVEL 1 /* preference item; 1 = make popup windows toplevel */
